@@ -1,8 +1,15 @@
 #ifndef DWGSIM_OPT_H
 #define DWGSIM_OPT_H
 
+#include "zlib.h"
+
 #define ERROR_RATE_NUM_RANDOM_READS 1000000
 
+#define OUTPUT_TYPE_ALL 0
+#define OUTPUT_TYPE_BWA 1
+#define OUTPUT_TYPE_BFAST 2
+
+
 typedef struct {
     double start, by, end;
 } error_t;
@@ -24,6 +31,7 @@ typedef struct {
     int32_t max_n;
     int32_t data_type;
     int32_t strandedness;
+    int32_t read_one_strand;
     int8_t *flow_order;
     int32_t flow_order_len;
     int32_t use_base_error;
@@ -37,12 +45,13 @@ typedef struct {
     char *fn_regions_bed;
     FILE *fp_mut;
     FILE *fp_vcf;
-    FILE *fp_bfast;
-    FILE *fp_bwa1;
-    FILE *fp_bwa2;
+    gzFile *fp_bfast;
+    gzFile *fp_bwa1;
+    gzFile *fp_bwa2;
     FILE *fp_fa;
     FILE *fp_fai;
     char *read_prefix;
+    int32_t output_type;
 } dwgsim_opt_t;
 
 dwgsim_opt_t* 
